# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .x_bitmap_palette import XBitmapPalette as XBitmapPalette_cf20e4a
from .x_integer_bitmap_color_space import XIntegerBitmapColorSpace as XIntegerBitmapColorSpace_b1691234


class IntegerBitmapLayout(object):
    """
    Struct Class

    This structure describes the memory layout of a bitmap having integer color channels.
    
    This structure collects all necessary information to describe the memory layout of a bitmap having integer color channels
    
    **since**
    
        OOo 2.0

    See Also:
        `API IntegerBitmapLayout <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1IntegerBitmapLayout.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.IntegerBitmapLayout'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.rendering.IntegerBitmapLayout'
    """Literal Constant ``com.sun.star.rendering.IntegerBitmapLayout``"""

    def __init__(self, ScanLines: typing.Optional[int] = 0, ScanLineBytes: typing.Optional[int] = 0, ScanLineStride: typing.Optional[int] = 0, PlaneStride: typing.Optional[int] = 0, ColorSpace: typing.Optional[XIntegerBitmapColorSpace_b1691234] = None, Palette: typing.Optional[XBitmapPalette_cf20e4a] = None, IsMsbFirst: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            ScanLines (int, optional): ScanLines value.
            ScanLineBytes (int, optional): ScanLineBytes value.
            ScanLineStride (int, optional): ScanLineStride value.
            PlaneStride (int, optional): PlaneStride value.
            ColorSpace (XIntegerBitmapColorSpace, optional): ColorSpace value.
            Palette (XBitmapPalette, optional): Palette value.
            IsMsbFirst (bool, optional): IsMsbFirst value.
        """
        super().__init__()

        if isinstance(ScanLines, IntegerBitmapLayout):
            oth: IntegerBitmapLayout = ScanLines
            self.ScanLines = oth.ScanLines
            self.ScanLineBytes = oth.ScanLineBytes
            self.ScanLineStride = oth.ScanLineStride
            self.PlaneStride = oth.PlaneStride
            self.ColorSpace = oth.ColorSpace
            self.Palette = oth.Palette
            self.IsMsbFirst = oth.IsMsbFirst
            return

        kargs = {
            "ScanLines": ScanLines,
            "ScanLineBytes": ScanLineBytes,
            "ScanLineStride": ScanLineStride,
            "PlaneStride": PlaneStride,
            "ColorSpace": ColorSpace,
            "Palette": Palette,
            "IsMsbFirst": IsMsbFirst,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._scan_lines = kwargs["ScanLines"]
        self._scan_line_bytes = kwargs["ScanLineBytes"]
        self._scan_line_stride = kwargs["ScanLineStride"]
        self._plane_stride = kwargs["PlaneStride"]
        self._color_space = kwargs["ColorSpace"]
        self._palette = kwargs["Palette"]
        self._is_msb_first = kwargs["IsMsbFirst"]


    @property
    def ScanLines(self) -> int:
        """
        Number of scanlines for this bitmap.
        
        This value must not be negative
        """
        return self._scan_lines

    @ScanLines.setter
    def ScanLines(self, value: int) -> None:
        self._scan_lines = value

    @property
    def ScanLineBytes(self) -> int:
        """
        Number of data bytes per scanline.
        
        This value must not be negative
        """
        return self._scan_line_bytes

    @ScanLineBytes.setter
    def ScanLineBytes(self, value: int) -> None:
        self._scan_line_bytes = value

    @property
    def ScanLineStride(self) -> int:
        """
        Byte offset between the start of two consecutive scanlines.
        
        This value is permitted to be negative, denoting a bitmap whose content is flipped at the x axis.
        """
        return self._scan_line_stride

    @ScanLineStride.setter
    def ScanLineStride(self, value: int) -> None:
        self._scan_line_stride = value

    @property
    def PlaneStride(self) -> int:
        """
        Byte offset between the start of two consecutive planes.
        
        This value is permitted to be negative. If this value is zero, the bitmap is assumed to be in chunky format, otherwise it is assumed to be planar. The difference between chunky and planar layout lies in the way how color channels are interleaved. For a chunky format, all channel data for a single pixel lies consecutively in memory. For a planar layout, the first channel of all pixel is stored consecutive, followed by the second channel, and so forth.
        """
        return self._plane_stride

    @PlaneStride.setter
    def PlaneStride(self, value: int) -> None:
        self._plane_stride = value

    @property
    def ColorSpace(self) -> XIntegerBitmapColorSpace_b1691234:
        """
        Color space the bitmap colors shall be interpreted within.
        
        Note that the actual pixel layout is specified at the color space. If this layout describes a palette bitmap format, this color space describes the index format (plus maybe an extra alpha channel). The palette itself references another color space, which describes the layout of the palette entries.
        """
        return self._color_space

    @ColorSpace.setter
    def ColorSpace(self, value: XIntegerBitmapColorSpace_b1691234) -> None:
        self._color_space = value

    @property
    def Palette(self) -> XBitmapPalette_cf20e4a:
        """
        This member determines whether the bitmap data are actually indices into a color map.
        
        When set to the nil reference, the bitmap data is assumed to contain direct color values (to be interpreted according to the associated color space). If this member references a valid palette, one of the pixel components as returned by the color space referenced from the ColorSpace is required to be of type ColorComponentTag.INDEX. That component is then used to index the palette.
        """
        return self._palette

    @Palette.setter
    def Palette(self, value: XBitmapPalette_cf20e4a) -> None:
        self._palette = value

    @property
    def IsMsbFirst(self) -> bool:
        """
        This member determines the bit order (only relevant if a pixel uses less than 8 bits, of course).
        
        When TRUE, this member denotes that the leftmost pixel from an 8 bit amount of pixel data consists of the bits starting with the most significant bit. When FALSE, it's starting with the least significant bit.
        
        Example: for a 1bpp bitmap, each pixel is represented by exactly one bit. If this member is TRUE, the first pixel is the MSB of the first byte, and the eighth pixel is the LSB of the first byte. If this member is FALSE, it's just the opposite.
        """
        return self._is_msb_first

    @IsMsbFirst.setter
    def IsMsbFirst(self, value: bool) -> None:
        self._is_msb_first = value


__all__ = ['IntegerBitmapLayout']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class MissingInputStreamException(Exception_85530a09):
    """
    Exception Class

    This exception is used to indicate that there is an com.sun.star.io.XInputStream missing.
    
    For example, the command \"insert\" may fail, if the implementation expects that an input stream is supplied with the given InsertCommandArgument.

    See Also:
        `API MissingInputStreamException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1MissingInputStreamException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.MissingInputStreamException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.ucb.MissingInputStreamException'
    __pyunostruct__: str = 'com.sun.star.ucb.MissingInputStreamException'

    typeName: str = 'com.sun.star.ucb.MissingInputStreamException'
    """Literal Constant ``com.sun.star.ucb.MissingInputStreamException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        super()._init(**kwargs)


__all__ = ['MissingInputStreamException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class PolygonFlags(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.PolygonFlags", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.PolygonFlags`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.PolygonFlags import CONTROL as POLYGON_FLAGS_CONTROL
        from com.sun.star.drawing.PolygonFlags import NORMAL as POLYGON_FLAGS_NORMAL
        from com.sun.star.drawing.PolygonFlags import SMOOTH as POLYGON_FLAGS_SMOOTH
        from com.sun.star.drawing.PolygonFlags import SYMMETRIC as POLYGON_FLAGS_SYMMETRIC

        class PolygonFlags(uno.Enum):
            """
            Enum Class


            See Also:
                `API PolygonFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#af3965fa427851bc02bfe32c5d95d7406>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.PolygonFlags', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.PolygonFlags'
            __ooo_type_name__: str = 'enum'

            CONTROL = POLYGON_FLAGS_CONTROL
            """
            the point is a control point, to control the curve from the user interface.
            """
            NORMAL = POLYGON_FLAGS_NORMAL
            """
            the text is drawn along the path without scaling.

            the point is normal, from the curve discussion view.
            """
            SMOOTH = POLYGON_FLAGS_SMOOTH
            """
            the point is smooth, the first derivation from the curve discussion view.

            With SMOOTH shading, the colors of the lit vertices is interpolated.
            """
            SYMMETRIC = POLYGON_FLAGS_SYMMETRIC
            """
            the point is symmetric, the second derivation from the curve discussion view.
            """
    else:
        # keep document generators happy
        from ...lo.drawing.polygon_flags import PolygonFlags as PolygonFlags


__all__ = ['PolygonFlags']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
import uno
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class PropertyAttribute(metaclass=UnoConstMeta, type_name="com.sun.star.beans.PropertyAttribute", name_space="com.sun.star.beans"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.beans.PropertyAttribute``"""
        pass

    class PropertyAttributeEnum(IntFlag, metaclass=ConstEnumMeta, type_name="com.sun.star.beans.PropertyAttribute", name_space="com.sun.star.beans"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.beans.PropertyAttribute`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.beans import PropertyAttribute as PropertyAttribute
    else:
        # keep document generators happy
        from ...lo.beans.property_attribute import PropertyAttribute as PropertyAttribute

    class PropertyAttributeEnum(IntFlag):
        """
        Enum of Const Class PropertyAttribute

        These values are used to specify the behavior of a Property.
        
        **since**
        
            OOo 1.1.2
        """
        MAYBEVOID = PropertyAttribute.MAYBEVOID
        """
        indicates that a property value can be void.
        
        It does not mean that the type of the property is void!
        """
        BOUND = PropertyAttribute.BOUND
        """
        indicates that a PropertyChangeEvent will be fired to all registered XPropertyChangeListeners whenever the value of this property changes.
        """
        CONSTRAINED = PropertyAttribute.CONSTRAINED
        """
        indicates that a PropertyChangeEvent will be fired to all registered XVetoableChangeListeners whenever the value of this property is about to change.
        """
        TRANSIENT = PropertyAttribute.TRANSIENT
        """
        indicates that the value of the property is not persistent.
        """
        READONLY = PropertyAttribute.READONLY
        """
        indicates that the value of the property is read-only.
        """
        MAYBEAMBIGUOUS = PropertyAttribute.MAYBEAMBIGUOUS
        """
        indicates that the value of the property can be ambiguous.
        """
        MAYBEDEFAULT = PropertyAttribute.MAYBEDEFAULT
        """
        indicates that the property can be set to default.
        """
        REMOVABLE = PropertyAttribute.REMOVABLE
        """
        indicates that the property can be removed (i.e., by calling XPropertyContainer.removeProperty()).
        """
        REMOVEABLE = PropertyAttribute.REMOVEABLE
        OPTIONAL = PropertyAttribute.OPTIONAL
        """
        indicates that a property is optional.
        
        This attribute is not of interest for concrete property implementations. It's needed for property specifications inside service specifications in UNOIDL.
        
        **since**
        
            OOo 1.1.2
        """

__all__ = ['PropertyAttribute', 'PropertyAttributeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from .prepared_statement import PreparedStatement as PreparedStatement_eef40d8c
from .x_out_parameters import XOutParameters as XOutParameters_c6db0c48
from .x_row import XRow as XRow_5f360834

class CallableStatement(PreparedStatement_eef40d8c, XOutParameters_c6db0c48, XRow_5f360834):
    """
    Service Class

    is used to execute SQL stored procedures.
    
    SDBC provides a stored procedure SQL escape that allows stored procedures to be called in a standard way for all RDBMSs. This escape syntax has one form that includes a result parameter and one that does not. If used, the result parameter must be registered as an OUT parameter. The other parameters can be used for input, output, or both. Parameters are referred to sequentially, by number. The first parameter is 1.
    
    {?=call&lt;procedure-name&gt;[&lt;arg1&gt;,&lt;arg2&gt;,...]}{call&lt;procedure-name&gt;[&lt;arg1&gt;,&lt;arg2&gt;,...]}
    
    IN parameter values are set using the set methods inherited from com.sun.star.sdbc.PreparedStatement . The type of all OUT parameters must be registered prior to executing the stored procedure; their values are retrieved after execution via the get methods provided by the com.sun.star.sdbc.XRow.
    
    A CallableStatement can return one com.sun.star.sdbc.XResultSet or multiple com.sun.star.sdbc.ResultSet objects. Multiple ResultSet objects are handled using operations inherited from com.sun.star.sdbc.XPreparedStatement.
    
    For maximum portability, a call's com.sun.star.sdbc.ResultSet objects and update counts should be processed prior to getting the values of output parameters.

    See Also:
        `API CallableStatement <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1CallableStatement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.CallableStatement'
    __ooo_type_name__: str = 'service'


__all__ = ['CallableStatement']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.xsd.boolean import Boolean as Boolean
from ...lo.xsd.data_type_class import DataTypeClass as DataTypeClass
from ...lo.xsd.date import Date as Date
from ...lo.xsd.date_time import DateTime as DateTime
from ...lo.xsd.day import Day as Day
from ...lo.xsd.decimal import Decimal as Decimal
from ...lo.xsd.month import Month as Month
from ...lo.xsd.string import String as String
from ...lo.xsd.time import Time as Time
from ...lo.xsd.white_space_treatment import WhiteSpaceTreatment as WhiteSpaceTreatment
from ...lo.xsd.x_data_type import XDataType as XDataType
from ...lo.xsd.year import Year as Year



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.document.ambigous_filter_request import AmbigousFilterRequest as AmbigousFilterRequest
with suppress(ImportError):
    from ...dyn.document.broken_package_request import BrokenPackageRequest as BrokenPackageRequest
with suppress(ImportError):
    from ...dyn.document.changed_by_others_request import ChangedByOthersRequest as ChangedByOthersRequest
with suppress(ImportError):
    from ...dyn.document.cmis_property import CmisProperty as CmisProperty
with suppress(ImportError):
    from ...dyn.document.cmis_version import CmisVersion as CmisVersion
with suppress(ImportError):
    from ...dyn.document.corrupted_filter_configuration_exception import CorruptedFilterConfigurationException as CorruptedFilterConfigurationException
with suppress(ImportError):
    from ...dyn.document.document_event import DocumentEvent as DocumentEvent
with suppress(ImportError):
    from ...dyn.document.document_properties import DocumentProperties as DocumentProperties
with suppress(ImportError):
    from ...dyn.document.document_revision_list_persistence import DocumentRevisionListPersistence as DocumentRevisionListPersistence
with suppress(ImportError):
    from ...dyn.document.empty_undo_stack_exception import EmptyUndoStackException as EmptyUndoStackException
with suppress(ImportError):
    from ...dyn.document.event_descriptor import EventDescriptor as EventDescriptor
with suppress(ImportError):
    from ...dyn.document.event_object import EventObject as EventObject
with suppress(ImportError):
    from ...dyn.document.events import Events as Events
with suppress(ImportError):
    from ...dyn.document.exotic_file_load_exception import ExoticFileLoadException as ExoticFileLoadException
with suppress(ImportError):
    from ...dyn.document.export_filter import ExportFilter as ExportFilter
with suppress(ImportError):
    from ...dyn.document.extended_type_detection import ExtendedTypeDetection as ExtendedTypeDetection
with suppress(ImportError):
    from ...dyn.document.extended_type_detection_factory import ExtendedTypeDetectionFactory as ExtendedTypeDetectionFactory
with suppress(ImportError):
    from ...dyn.document.filter_adapter import FilterAdapter as FilterAdapter
with suppress(ImportError):
    from ...dyn.document.filter_config_refresh import FilterConfigRefresh as FilterConfigRefresh
with suppress(ImportError):
    from ...dyn.document.filter_factory import FilterFactory as FilterFactory
with suppress(ImportError):
    from ...dyn.document.filter_options_request import FilterOptionsRequest as FilterOptionsRequest
with suppress(ImportError):
    from ...dyn.document.graphic_storage_handler import GraphicStorageHandler as GraphicStorageHandler
with suppress(ImportError):
    from ...dyn.document.header_footer_settings import HeaderFooterSettings as HeaderFooterSettings
with suppress(ImportError):
    from ...dyn.document.import_filter import ImportFilter as ImportFilter
with suppress(ImportError):
    from ...dyn.document.indexed_property_values import IndexedPropertyValues as IndexedPropertyValues
with suppress(ImportError):
    from ...dyn.document.link_target import LinkTarget as LinkTarget
with suppress(ImportError):
    from ...dyn.document.link_targets import LinkTargets as LinkTargets
with suppress(ImportError):
    from ...dyn.document.link_update_modes import LinkUpdateModes as LinkUpdateModes
with suppress(ImportError):
    from ...dyn.document.link_update_modes import LinkUpdateModesEnum as LinkUpdateModesEnum
with suppress(ImportError):
    from ...dyn.document.lock_file_corrupt_request import LockFileCorruptRequest as LockFileCorruptRequest
with suppress(ImportError):
    from ...dyn.document.lock_file_ignore_request import LockFileIgnoreRequest as LockFileIgnoreRequest
with suppress(ImportError):
    from ...dyn.document.locked_document_request import LockedDocumentRequest as LockedDocumentRequest
with suppress(ImportError):
    from ...dyn.document.locked_on_saving_request import LockedOnSavingRequest as LockedOnSavingRequest
with suppress(ImportError):
    from ...dyn.document.macro_exec_mode import MacroExecMode as MacroExecMode
with suppress(ImportError):
    from ...dyn.document.macro_exec_mode import MacroExecModeEnum as MacroExecModeEnum
with suppress(ImportError):
    from ...dyn.document.media_descriptor import MediaDescriptor as MediaDescriptor
with suppress(ImportError):
    from ...dyn.document.named_property_values import NamedPropertyValues as NamedPropertyValues
with suppress(ImportError):
    from ...dyn.document.no_such_filter_request import NoSuchFilterRequest as NoSuchFilterRequest
with suppress(ImportError):
    from ...dyn.document.ooxml_document_properties_importer import OOXMLDocumentPropertiesImporter as OOXMLDocumentPropertiesImporter
with suppress(ImportError):
    from ...dyn.document.office_document import OfficeDocument as OfficeDocument
with suppress(ImportError):
    from ...dyn.document.ole_embedded_server_registration import OleEmbeddedServerRegistration as OleEmbeddedServerRegistration
with suppress(ImportError):
    from ...dyn.document.own_lock_on_document_request import OwnLockOnDocumentRequest as OwnLockOnDocumentRequest
with suppress(ImportError):
    from ...dyn.document.pdf_dialog import PDFDialog as PDFDialog
with suppress(ImportError):
    from ...dyn.document.printer_independent_layout import PrinterIndependentLayout as PrinterIndependentLayout
with suppress(ImportError):
    from ...dyn.document.printer_independent_layout import PrinterIndependentLayoutEnum as PrinterIndependentLayoutEnum
with suppress(ImportError):
    from ...dyn.document.redline_display_type import RedlineDisplayType as RedlineDisplayType
with suppress(ImportError):
    from ...dyn.document.redline_display_type import RedlineDisplayTypeEnum as RedlineDisplayTypeEnum
with suppress(ImportError):
    from ...dyn.document.reload_editable_request import ReloadEditableRequest as ReloadEditableRequest
with suppress(ImportError):
    from ...dyn.document.settings import Settings as Settings
with suppress(ImportError):
    from ...dyn.document.type_detection import TypeDetection as TypeDetection
with suppress(ImportError):
    from ...dyn.document.undo_context_not_closed_exception import UndoContextNotClosedException as UndoContextNotClosedException
with suppress(ImportError):
    from ...dyn.document.undo_failed_exception import UndoFailedException as UndoFailedException
with suppress(ImportError):
    from ...dyn.document.undo_manager_event import UndoManagerEvent as UndoManagerEvent
with suppress(ImportError):
    from ...dyn.document.update_doc_mode import UpdateDocMode as UpdateDocMode
with suppress(ImportError):
    from ...dyn.document.update_doc_mode import UpdateDocModeEnum as UpdateDocModeEnum
with suppress(ImportError):
    from ...dyn.document.x_action_lockable import XActionLockable as XActionLockable
with suppress(ImportError):
    from ...dyn.document.x_binary_stream_resolver import XBinaryStreamResolver as XBinaryStreamResolver
with suppress(ImportError):
    from ...dyn.document.x_cmis_document import XCmisDocument as XCmisDocument
with suppress(ImportError):
    from ...dyn.document.x_code_name_query import XCodeNameQuery as XCodeNameQuery
with suppress(ImportError):
    from ...dyn.document.x_compat_writer_doc_properties import XCompatWriterDocProperties as XCompatWriterDocProperties
with suppress(ImportError):
    from ...dyn.document.x_document_event_broadcaster import XDocumentEventBroadcaster as XDocumentEventBroadcaster
with suppress(ImportError):
    from ...dyn.document.x_document_event_listener import XDocumentEventListener as XDocumentEventListener
with suppress(ImportError):
    from ...dyn.document.x_document_insertable import XDocumentInsertable as XDocumentInsertable
with suppress(ImportError):
    from ...dyn.document.x_document_languages import XDocumentLanguages as XDocumentLanguages
with suppress(ImportError):
    from ...dyn.document.x_document_properties import XDocumentProperties as XDocumentProperties
with suppress(ImportError):
    from ...dyn.document.x_document_properties_supplier import XDocumentPropertiesSupplier as XDocumentPropertiesSupplier
with suppress(ImportError):
    from ...dyn.document.x_document_recovery import XDocumentRecovery as XDocumentRecovery
with suppress(ImportError):
    from ...dyn.document.x_document_revision_list_persistence import XDocumentRevisionListPersistence as XDocumentRevisionListPersistence
with suppress(ImportError):
    from ...dyn.document.x_document_sub_storage_supplier import XDocumentSubStorageSupplier as XDocumentSubStorageSupplier
with suppress(ImportError):
    from ...dyn.document.x_embedded_object_resolver import XEmbeddedObjectResolver as XEmbeddedObjectResolver
with suppress(ImportError):
    from ...dyn.document.x_embedded_object_supplier import XEmbeddedObjectSupplier as XEmbeddedObjectSupplier
with suppress(ImportError):
    from ...dyn.document.x_embedded_object_supplier2 import XEmbeddedObjectSupplier2 as XEmbeddedObjectSupplier2
with suppress(ImportError):
    from ...dyn.document.x_embedded_scripts import XEmbeddedScripts as XEmbeddedScripts
with suppress(ImportError):
    from ...dyn.document.x_event_broadcaster import XEventBroadcaster as XEventBroadcaster
with suppress(ImportError):
    from ...dyn.document.x_event_listener import XEventListener as XEventListener
with suppress(ImportError):
    from ...dyn.document.x_events_supplier import XEventsSupplier as XEventsSupplier
with suppress(ImportError):
    from ...dyn.document.x_exporter import XExporter as XExporter
with suppress(ImportError):
    from ...dyn.document.x_extended_filter_detection import XExtendedFilterDetection as XExtendedFilterDetection
with suppress(ImportError):
    from ...dyn.document.x_filter import XFilter as XFilter
with suppress(ImportError):
    from ...dyn.document.x_filter_adapter import XFilterAdapter as XFilterAdapter
with suppress(ImportError):
    from ...dyn.document.x_graphic_object_resolver import XGraphicObjectResolver as XGraphicObjectResolver
with suppress(ImportError):
    from ...dyn.document.x_graphic_storage_handler import XGraphicStorageHandler as XGraphicStorageHandler
with suppress(ImportError):
    from ...dyn.document.x_importer import XImporter as XImporter
with suppress(ImportError):
    from ...dyn.document.x_interaction_filter_options import XInteractionFilterOptions as XInteractionFilterOptions
with suppress(ImportError):
    from ...dyn.document.x_interaction_filter_select import XInteractionFilterSelect as XInteractionFilterSelect
with suppress(ImportError):
    from ...dyn.document.x_link_target_supplier import XLinkTargetSupplier as XLinkTargetSupplier
with suppress(ImportError):
    from ...dyn.document.xml_basic_exporter import XMLBasicExporter as XMLBasicExporter
with suppress(ImportError):
    from ...dyn.document.xml_oasis_basic_exporter import XMLOasisBasicExporter as XMLOasisBasicExporter
with suppress(ImportError):
    from ...dyn.document.x_mime_type_info import XMimeTypeInfo as XMimeTypeInfo
with suppress(ImportError):
    from ...dyn.document.xooxml_document_properties_importer import XOOXMLDocumentPropertiesImporter as XOOXMLDocumentPropertiesImporter
with suppress(ImportError):
    from ...dyn.document.x_redlines_supplier import XRedlinesSupplier as XRedlinesSupplier
with suppress(ImportError):
    from ...dyn.document.x_script_invocation_context import XScriptInvocationContext as XScriptInvocationContext
with suppress(ImportError):
    from ...dyn.document.x_shape_event_broadcaster import XShapeEventBroadcaster as XShapeEventBroadcaster
with suppress(ImportError):
    from ...dyn.document.x_shape_event_listener import XShapeEventListener as XShapeEventListener
with suppress(ImportError):
    from ...dyn.document.x_storage_based_document import XStorageBasedDocument as XStorageBasedDocument
with suppress(ImportError):
    from ...dyn.document.x_storage_change_listener import XStorageChangeListener as XStorageChangeListener
with suppress(ImportError):
    from ...dyn.document.x_type_detection import XTypeDetection as XTypeDetection
with suppress(ImportError):
    from ...dyn.document.x_undo_action import XUndoAction as XUndoAction
with suppress(ImportError):
    from ...dyn.document.x_undo_manager import XUndoManager as XUndoManager
with suppress(ImportError):
    from ...dyn.document.x_undo_manager_listener import XUndoManagerListener as XUndoManagerListener
with suppress(ImportError):
    from ...dyn.document.x_undo_manager_supplier import XUndoManagerSupplier as XUndoManagerSupplier
with suppress(ImportError):
    from ...dyn.document.x_vba_method_parameter import XVbaMethodParameter as XVbaMethodParameter
with suppress(ImportError):
    from ...dyn.document.x_view_data_supplier import XViewDataSupplier as XViewDataSupplier
with suppress(ImportError):
    from ...dyn.document.xxml_basic_exporter import XXMLBasicExporter as XXMLBasicExporter



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt.grid
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ...lang.event_object import EventObject as EventObject_a3d70b03
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing


class GridDataEvent(EventObject_a3d70b03):
    """
    Struct Class

    used to notify changes in the data represented by an XMutableGridDataModel.
    
    Effectively, a GridDataEvent denotes a continuous two-dimensional cell range within a grid's data model, which is affected by a certain change.
    
    **since**
    
        OOo 3.3

    See Also:
        `API GridDataEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridDataEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.grid'
    __ooo_full_ns__: str = 'com.sun.star.awt.grid.GridDataEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.grid.GridDataEvent'
    """Literal Constant ``com.sun.star.awt.grid.GridDataEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, FirstColumn: typing.Optional[int] = 0, LastColumn: typing.Optional[int] = 0, FirstRow: typing.Optional[int] = 0, LastRow: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            FirstColumn (int, optional): FirstColumn value.
            LastColumn (int, optional): LastColumn value.
            FirstRow (int, optional): FirstRow value.
            LastRow (int, optional): LastRow value.
        """

        if isinstance(Source, GridDataEvent):
            oth: GridDataEvent = Source
            self.Source = oth.Source
            self.FirstColumn = oth.FirstColumn
            self.LastColumn = oth.LastColumn
            self.FirstRow = oth.FirstRow
            self.LastRow = oth.LastRow
            return

        kargs = {
            "Source": Source,
            "FirstColumn": FirstColumn,
            "LastColumn": LastColumn,
            "FirstRow": FirstRow,
            "LastRow": LastRow,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._first_column = kwargs["FirstColumn"]
        self._last_column = kwargs["LastColumn"]
        self._first_row = kwargs["FirstRow"]
        self._last_row = kwargs["LastRow"]
        inst_keys = ('FirstColumn', 'LastColumn', 'FirstRow', 'LastRow')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def FirstColumn(self) -> int:
        """
        denotes the first column affected by a change.
        
        If FirstColumn is -1, the listener should assume that all rows of a grid's data model are affected.
        """
        return self._first_column

    @FirstColumn.setter
    def FirstColumn(self, value: int) -> None:
        self._first_column = value

    @property
    def LastColumn(self) -> int:
        """
        denotes the last column affected by a change
        """
        return self._last_column

    @LastColumn.setter
    def LastColumn(self, value: int) -> None:
        self._last_column = value

    @property
    def FirstRow(self) -> int:
        """
        denotes the first row affected by a change.
        
        If FirstRow is -1, the listener should assume that all rows of a grid's data model are affected.
        """
        return self._first_row

    @FirstRow.setter
    def FirstRow(self, value: int) -> None:
        self._first_row = value

    @property
    def LastRow(self) -> int:
        """
        denotes the last row affected by a change
        """
        return self._last_row

    @LastRow.setter
    def LastRow(self, value: int) -> None:
        self._last_row = value


__all__ = ['GridDataEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from .color_component import ColorComponent as ColorComponent_e4c0e78
    from .x_color_space import XColorSpace as XColorSpace_e3940d09
    from .x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D_e1b0e20

class XParametricPolyPolygon2D(XInterface_8f010a43):
    """
    Interface to a dynamic poly-polygon generator, that generates poly-polygons depending on a given parameter value.
    
    The returned poly-polygon should normally be contained in the [0,1]x[0,1] rectangle. At least that is the dimension expected at other places. e.g. Texture.

    See Also:
        `API XParametricPolyPolygon2D <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XParametricPolyPolygon2D.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XParametricPolyPolygon2D'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XParametricPolyPolygon2D'

    @abstractmethod
    def getColor(self, t: float) -> typing.Tuple[ColorComponent_e4c0e78, ...]:
        """
        Query the color value for the polygonal area at the specified parameter value.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getColorSpace(self) -> XColorSpace_e3940d09:
        """
        Query the color space employed by this object.
        """
        ...
    @abstractmethod
    def getOutline(self, t: float) -> XPolyPolygon2D_e1b0e20:
        """
        Query the polygonal outline at the specified value.
        
        The returned outline should be clipped to the [0,1]x[0,1] rectangle.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getPointColor(self, point: RealPoint2D_d6e70c78) -> typing.Tuple[ColorComponent_e4c0e78, ...]:
        """
        Query the color for a dedicated point in the plane.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XParametricPolyPolygon2D']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class AttributeData(object):
    """
    Struct Class

    store the type and value of an XML attribute inside a XNameContainer

    See Also:
        `API AttributeData <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1AttributeData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml'
    __ooo_full_ns__: str = 'com.sun.star.xml.AttributeData'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.xml.AttributeData'
    """Literal Constant ``com.sun.star.xml.AttributeData``"""

    def __init__(self, Namespace: typing.Optional[str] = '', Type: typing.Optional[str] = '', Value: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Namespace (str, optional): Namespace value.
            Type (str, optional): Type value.
            Value (str, optional): Value value.
        """
        super().__init__()

        if isinstance(Namespace, AttributeData):
            oth: AttributeData = Namespace
            self.Namespace = oth.Namespace
            self.Type = oth.Type
            self.Value = oth.Value
            return

        kargs = {
            "Namespace": Namespace,
            "Type": Type,
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._namespace = kwargs["Namespace"]
        self._type = kwargs["Type"]
        self._value = kwargs["Value"]


    @property
    def Namespace(self) -> str:
        """
        the namespace of this XML attribute.
        
        This string can be empty if you are not using namespaces.
        """
        return self._namespace

    @Namespace.setter
    def Namespace(self, value: str) -> None:
        self._namespace = value

    @property
    def Type(self) -> str:
        """
        the type of this XML attribute.
        
        For non validating parsers this must be CDATA.
        """
        return self._type

    @Type.setter
    def Type(self, value: str) -> None:
        self._type = value

    @property
    def Value(self) -> str:
        """
        the string value of this XML attribute.
        """
        return self._value

    @Value.setter
    def Value(self, value: str) -> None:
        self._value = value


__all__ = ['AttributeData']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.style
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_style_loader import XStyleLoader as XStyleLoader_be2a0bf9
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XStyleLoader2(XStyleLoader_be2a0bf9):
    """
    extends XStyleLoader interface to import styles from an already opened component.
    
    **since**
    
        LibreOffice 4.4

    See Also:
        `API XStyleLoader2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1style_1_1XStyleLoader2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.XStyleLoader2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.style.XStyleLoader2'

    @abstractmethod
    def loadStylesFromDocument(self, aSourceComponent: XComponent_98dc0ab5, aOptions: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        loads styles from a given document
        
        As the default, all supported style families are loaded and existing styles are overwritten.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XStyleLoader2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed


class EmbedStates(object):
    """
    Const Class

    This constant set contains possible states for EmbeddedObject.

    See Also:
        `API EmbedStates <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EmbedStates.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.EmbedStates'
    __ooo_type_name__: str = 'const'

    LOADED = 0
    """
    \"Loaded\" - the persistent representation of the object is loaded in memory.
    
    The object is created and assigned with a persistent entry, and a view representation ( metafile and etc. ) can be retrieved ( if there is any ).
    """
    RUNNING = 1
    """
    \"Running\" - the object is connected and loaded.
    
    The object has a connection to the container client and a component loaded from persistent entry. In case of internal document it also means existing of document model that implements com.sun.star.frame.XModel interface.
    """
    ACTIVE = 2
    """
    \"Active\" - the object is activated in separate window ( outplace activation ).
    """
    INPLACE_ACTIVE = 3
    """
    \"Inplace active\" - the object has own window in the container's window.
    
    The object is activated and has its own window in the container's window that allows object to process mouse events and control own rendering.
    """
    UI_ACTIVE = 4
    """
    \"UI active\" - the inplace active object that has user interface.
    
    The object is inplace active, allowed to have menus, toolbars, keyboard accelerators, and has the focus.
    """

__all__ = ['EmbedStates']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class NumberFormatProperties(ABC):
    """
    Service Class

    contains properties specifying the behavior of a NumberFormatter.

    See Also:
        `API NumberFormatProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1NumberFormatProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.NumberFormatProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Comment(self) -> str:
        """
        contains a comment regarding the number format for display to the user.
        """
        ...

    @abstractproperty
    def FormatString(self) -> str:
        """
        contains the format string of the number format.
        """
        ...

    @abstractproperty
    def Locale(self) -> Locale_70d308fa:
        """
        contains the locale of the number format.
        """
        ...

    @abstractproperty
    def Type(self) -> int:
        """
        contains the type of the number format.
        """
        ...


__all__ = ['NumberFormatProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.grid
from __future__ import annotations
import typing
from abc import abstractproperty
from ..uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from ..font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from .x_grid_column_model import XGridColumnModel as XGridColumnModel_16290e65
    from .x_grid_data_model import XGridDataModel as XGridDataModel_f8b20d71
    from ...util.color import Color as Color_68e908c5
    from com.sun.star.view.SelectionType import SelectionTypeProto
    from com.sun.star.style.VerticalAlignment import VerticalAlignmentProto

class UnoControlGridModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a UnoControlGrid control.
    
    **since**
    
        OOo 3.3

    See Also:
        `API UnoControlGridModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1grid_1_1UnoControlGridModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.grid'
    __ooo_full_ns__: str = 'com.sun.star.awt.grid.UnoControlGridModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def RowBackgroundColors(self) -> typing.Tuple[Color_68e908c5, ...]:
        """
        specifies the colors to be used as background for data rows.
        
        If this sequence is non-empty, the data rows will be rendered with alternating background colors: Assuming the sequence has n elements, each row will use the background color as specified by its number's remainder modulo n.
        
        If this sequence is empty, all rows will use the same background color as the control as whole.
        
        If this property has a value of VOID, rows will be painted in alternating background colors, every second row having a background color derived from the control's selection color.
        """
        ...

    @abstractproperty
    def ActiveSelectionBackgroundColor(self) -> Color_68e908c5:
        """
        specifies the color to be used when drawing the background of selected cells, while the control has the focus.
        
        If this property has a value of VOID, the grid control renderer will use some default color, depending on the control's style settings.
        """
        ...

    @abstractproperty
    def ActiveSelectionTextColor(self) -> Color_68e908c5:
        """
        specifies the color to be used when drawing the text of selected cells, while the control has the focus.
        
        If this property has a value of VOID, the grid control renderer will use some default color, depending on the control's style settings.
        """
        ...

    @abstractproperty
    def ColumnHeaderHeight(self) -> int:
        """
        specifies the height of the column header row, if applicable.
        
        The height is specified in application font units - see com.sun.star.util.MeasureUnit.
        
        The value given here is ignored if ShowColumnHeader is FALSE.
        
        If the property is VOID, the grid control shall automatically determine a height which conveniently allows, according to the used font, to display one line of text.
        """
        ...

    @abstractproperty
    def ColumnModel(self) -> XGridColumnModel_16290e65:
        """
        Specifies the XGridColumnModel that is providing the column structure.
        
        You can implement your own instance of XGridColumnModel or use the DefaultGridColumnModel.
        
        The column model is in the ownership of the grid model: When you set a new column model, or dispose the grid model, then the (old) column model is disposed, too.
        
        The default for this property is an empty instance of the DefaultGridColumnModel.
        """
        ...

    @abstractproperty
    def FontDescriptor(self) -> FontDescriptor_bc110c0a:
        """
        specifies the font attributes of the text in the control.
        """
        ...

    @abstractproperty
    def FontEmphasisMark(self) -> int:
        """
        specifies the com.sun.star.text.FontEmphasis value of the text in the control.
        """
        ...

    @abstractproperty
    def FontRelief(self) -> int:
        """
        specifies the com.sun.star.text.FontRelief value of the text in the control.
        """
        ...

    @abstractproperty
    def GridDataModel(self) -> XGridDataModel_f8b20d71:
        """
        Specifies the XGridDataModel that is providing the hierarchical data.
        
        You can implement your own instance of XGridDataModel or use the DefaultGridDataModel.
        
        The data model is in the ownership of the grid model: When you set a new data model, or dispose the grid model, then the (old) data model is disposed, too.
        
        The default for this property is an empty instance of the DefaultGridDataModel.
        """
        ...

    @abstractproperty
    def GridLineColor(self) -> Color_68e908c5:
        """
        specifies the color to be used when drawing lines between cells
        
        If this property has a value of VOID, the grid control renderer will use some default color, depending on the control's style settings.
        """
        ...

    @abstractproperty
    def HScroll(self) -> bool:
        """
        Specifies the vertical scrollbar mode.
        
        The default value is FALSE
        """
        ...

    @abstractproperty
    def HeaderBackgroundColor(self) -> Color_68e908c5:
        """
        specifies the color to be used when drawing the background of row or column headers
        
        If this property has a value of VOID, the grid control renderer will use some default color, depending on the control's style settings.
        """
        ...

    @abstractproperty
    def HeaderTextColor(self) -> Color_68e908c5:
        """
        specifies the color to be used when drawing the text within row or column headers
        
        If this property has a value of VOID, the grid control renderer will use some default color, depending on the control's style settings.
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the control.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the control.
        """
        ...

    @abstractproperty
    def InactiveSelectionBackgroundColor(self) -> Color_68e908c5:
        """
        specifies the color to be used when drawing the background of selected cells, while the control does not have the focus.
        
        If this property has a value of VOID, the grid control renderer will use some default color, depending on the control's style settings.
        """
        ...

    @abstractproperty
    def InactiveSelectionTextColor(self) -> Color_68e908c5:
        """
        specifies the color to be used when drawing the text of selected cells, while the control does not have the focus.
        
        If this property has a value of VOID, the grid control renderer will use some default color, depending on the control's style settings.
        """
        ...

    @abstractproperty
    def RowHeaderWidth(self) -> int:
        """
        specifies the width of the row header column, if applicable.
        
        The width is specified in application font units - see com.sun.star.util.MeasureUnit.
        
        The value given here is ignored if ShowRowHeader is FALSE.
        """
        ...

    @abstractproperty
    def RowHeight(self) -> int:
        """
        Specifies the height of rows in the grid control.
        
        The height is specified in application font units - see com.sun.star.util.MeasureUnit.
        """
        ...

    @abstractproperty
    def SelectionModel(self) -> SelectionTypeProto:
        """
        Specifies the selection mode that is enabled for this grid control.
        
        The default value is com.sun.star.view.SelectionType.SINGLE
        """
        ...

    @abstractproperty
    def ShowColumnHeader(self) -> bool:
        """
        Specifies whether the grid control should display a title row.
        
        The default value is TRUE
        """
        ...

    @abstractproperty
    def ShowRowHeader(self) -> bool:
        """
        Specifies whether the grid control should display a special header column.
        
        The default value is FALSE
        """
        ...

    @abstractproperty
    def Tabstop(self) -> bool:
        """
        Specifies that the control can be reached with the TAB key.
        """
        ...

    @abstractproperty
    def TextColor(self) -> Color_68e908c5:
        """
        specifies the color to be used when drawing cell texts
        
        If this property has a value of VOID, the grid control renderer will use some default color, depending on the control's style settings.
        """
        ...

    @abstractproperty
    def TextLineColor(self) -> Color_68e908c5:
        """
        specifies the color to be used when drawing text lines (underlining and strikethrough)
        
        If this property has a value of VOID, the grid control renderer will use some default color, depending on the control's style settings.
        """
        ...

    @abstractproperty
    def UseGridLines(self) -> bool:
        """
        controls whether or not to paint horizontal and vertical lines between the grid cells.
        """
        ...

    @abstractproperty
    def VScroll(self) -> bool:
        """
        Specifies the horizontal scrollbar mode.
        
        The default value is FALSE
        """
        ...

    @abstractproperty
    def VerticalAlign(self) -> VerticalAlignmentProto:
        """
        specifies the vertical alignment of the content in the control.
        """
        ...


__all__ = ['UnoControlGridModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs


class CommonFilePickerElementIds(object):
    """
    Const Class

    These constants are used to specify common controls of a FilePicker dialog.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API CommonFilePickerElementIds <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1CommonFilePickerElementIds.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.CommonFilePickerElementIds'
    __ooo_type_name__: str = 'const'

    PUSHBUTTON_OK = 1
    """
    The control id of the OK button.
    """
    PUSHBUTTON_CANCEL = 2
    """
    The control id of the Cancel button.
    """
    LISTBOX_FILTER = 3
    """
    The filter listbox of a FilePicker dialog.
    """
    CONTROL_FILEVIEW = 4
    """
    Is used to refer to the file view of the file picker.
    
    This view shows the list of all files/folders in the currently selected folder.
    """
    EDIT_FILEURL = 5
    """
    Is used to refer to the edit line where a file or path can be entered by the user.
    """
    LISTBOX_FILTER_LABEL = 6
    """
    The label of the filter listbox of a FilePicker dialog.
    
    **since**
    
        OOo 1.1.2
    """
    EDIT_FILEURL_LABEL = 7
    """
    The label of the file name listbox of a FilePicker dialog.
    
    **since**
    
        OOo 1.1.2
    """

__all__ = ['CommonFilePickerElementIds']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6

class ModuleUICommandDescription(XNameAccess_e2ab0cf6):
    """
    Service Class

    a service which provides information about the user interface commands of a single module.
    
    Every OpenOffice.org module has an amount of commands that can be used by user interface elements. This service provides access to the user interface commands that are part of a single OpenOffice.org module, like Writer or Calc.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ModuleUICommandDescription <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ModuleUICommandDescription.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ModuleUICommandDescription'
    __ooo_type_name__: str = 'service'


__all__ = ['ModuleUICommandDescription']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations


class AnimationNodeType(object):
    """
    Const Class

    This constants defines a type for an animation node.
    
    It can be used to quickly identify semantic blocks inside an animation hierarchy.
    
    **since**
    
        LibreOffice 7.1

    See Also:
        `API AnimationNodeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1AnimationNodeType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.AnimationNodeType'
    __ooo_type_name__: str = 'const'

    CUSTOM = 0
    """
    Defines a custom time node.
    """
    PAR = 1
    """
    Defines a parallel time container.
    """
    SEQ = 2
    """
    Defines a sequence time container.
    """
    ITERATE = 3
    """
    Defines an iterate time container.
    """
    ANIMATE = 4
    """
    Defines a generic attribute animation.
    """
    SET = 5
    """
    Defines a simple mean of just setting the value of an attribute for a specified duration.
    """
    ANIMATEMOTION = 6
    """
    Defines a move animation along a path.
    """
    ANIMATECOLOR = 7
    """
    Defines an animation of a color attribute.
    """
    ANIMATETRANSFORM = 8
    """
    Defines an animation of a transformation attribute.
    """
    TRANSITIONFILTER = 9
    """
    Defines an animation of a filter behavior.
    """
    AUDIO = 10
    """
    Defines an audio effect.
    """
    COMMAND = 11
    """
    Defines a command effect.
    """
    ANIMATEPHYSICS = 12
    """
    Defines a physics animation.
    
    **since**
    
        LibreOffice 7.1
    """

__all__ = ['AnimationNodeType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml
from __future__ import annotations
from .x_export_filter import XExportFilter as XExportFilter_b0c20b99
from .sax.x_document_handler import XDocumentHandler as XDocumentHandler_9b90e28

class ExportFilter(XExportFilter_b0c20b99, XDocumentHandler_9b90e28):
    """
    Service Class

    describes an export filter for XML-based file formats.
    
    First, the XExportFilter.exporter() method must be called to provide the export component with the target location to which the data should be exported. Then, the source document's XML representation will be generated by calling the appropriate methods of the com.sun.star.xml.sax.XDocumentHandler interface. Error conditions must be signaled by throwing a com.sun.star.xml.sax.SAXException in the com.sun.star.xml.sax.XDocumentHandler calls.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API ExportFilter <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1xml_1_1ExportFilter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml'
    __ooo_full_ns__: str = 'com.sun.star.xml.ExportFilter'
    __ooo_type_name__: str = 'service'


__all__ = ['ExportFilter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..drawing.alignment import Alignment as Alignment_b1400b93


class RelativePosition(object):
    """
    Struct Class

    Determines a position of an object relative to a size defined by other means.
    
    Values from 0 to 1 cover the entire reference rectangle. Values may also be outside this range, especially negative.

    See Also:
        `API RelativePosition <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1RelativePosition.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.RelativePosition'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart2.RelativePosition'
    """Literal Constant ``com.sun.star.chart2.RelativePosition``"""

    def __init__(self, Primary: typing.Optional[float] = 0.0, Secondary: typing.Optional[float] = 0.0, Anchor: typing.Optional[Alignment_b1400b93] = Alignment_b1400b93.TOP_LEFT) -> None:
        """
        Constructor

        Arguments:
            Primary (float, optional): Primary value.
            Secondary (float, optional): Secondary value.
            Anchor (Alignment, optional): Anchor value.
        """
        super().__init__()

        if isinstance(Primary, RelativePosition):
            oth: RelativePosition = Primary
            self.Primary = oth.Primary
            self.Secondary = oth.Secondary
            self.Anchor = oth.Anchor
            return

        kargs = {
            "Primary": Primary,
            "Secondary": Secondary,
            "Anchor": Anchor,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._primary = kwargs["Primary"]
        self._secondary = kwargs["Secondary"]
        self._anchor = kwargs["Anchor"]


    @property
    def Primary(self) -> float:
        """
        The position in the primary direction.
        
        The direction is defined by the object using this point.
        
        For example for western languages the primary direction may be the horizontal distance measured from left to right.
        
        The values are relative to a reference size (for example the page size). Values between 0 and 1 span the complete bounding rectangle.
        """
        return self._primary

    @Primary.setter
    def Primary(self, value: float) -> None:
        self._primary = value

    @property
    def Secondary(self) -> float:
        """
        The position in the secondary direction.
        
        The direction is defined by the object using this point.
        
        For example for western languages the secondary direction may be the vertical distance measured from top to bottom.
        
        The values are relative to a reference size (for example the page size). Values between 0 and 1 span the complete bounding rectangle.
        """
        return self._secondary

    @Secondary.setter
    def Secondary(self, value: float) -> None:
        self._secondary = value

    @property
    def Anchor(self) -> Alignment_b1400b93:
        """
        This indicates how the object is placed at the relative position.
        
        The Anchor indicates which point of the placed object will be placed at the coordinates given within Primary and Secondary.
        
        For example if Anchor is TOP_LEFT the top left corner of an object will be placed at the given coordinates. If Anchor is RIGHT the right middle corner of the object will be placed at the given coordinates.
        """
        return self._anchor

    @Anchor.setter
    def Anchor(self, value: Alignment_b1400b93) -> None:
        self._anchor = value


__all__ = ['RelativePosition']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_adjustment_listener import XAdjustmentListener as XAdjustmentListener_fdfc0e11

class XScrollBar(XInterface_8f010a43):
    """
    gives access to the value and settings of a scroll bar and makes it possible to register adjustment event listeners.

    See Also:
        `API XScrollBar <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XScrollBar.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XScrollBar'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XScrollBar'

    @abstractmethod
    def addAdjustmentListener(self, l: XAdjustmentListener_fdfc0e11) -> None:
        """
        registers an adjustment event listener.
        """
        ...
    @abstractmethod
    def getBlockIncrement(self) -> int:
        """
        returns the currently set increment for a block move.
        """
        ...
    @abstractmethod
    def getLineIncrement(self) -> int:
        """
        returns the currently set increment for a single line move.
        """
        ...
    @abstractmethod
    def getMaximum(self) -> int:
        """
        returns the currently set maximum scroll value of the scroll bar.
        """
        ...
    @abstractmethod
    def getOrientation(self) -> int:
        """
        returns the currently set ScrollBarOrientation of the scroll bar.
        """
        ...
    @abstractmethod
    def getValue(self) -> int:
        """
        returns the current scroll value of the scroll bar.
        """
        ...
    @abstractmethod
    def getVisibleSize(self) -> int:
        """
        returns the currently visible size of the scroll bar.
        """
        ...
    @abstractmethod
    def removeAdjustmentListener(self, l: XAdjustmentListener_fdfc0e11) -> None:
        """
        unregisters an adjustment event listener.
        """
        ...
    @abstractmethod
    def setBlockIncrement(self, n: int) -> None:
        """
        sets the increment for a block move.
        """
        ...
    @abstractmethod
    def setLineIncrement(self, n: int) -> None:
        """
        sets the increment for a single line move.
        """
        ...
    @abstractmethod
    def setMaximum(self, n: int) -> None:
        """
        sets the maximum scroll value of the scroll bar.
        """
        ...
    @abstractmethod
    def setOrientation(self, n: int) -> None:
        """
        sets the ScrollBarOrientation of the scroll bar.
        """
        ...
    @abstractmethod
    def setValue(self, n: int) -> None:
        """
        sets the scroll value of the scroll bar.
        """
        ...
    @abstractmethod
    def setValues(self, nValue: int, nVisible: int, nMax: int) -> None:
        """
        sets the scroll value, visible area and maximum scroll value of the scroll bar.
        """
        ...
    @abstractmethod
    def setVisibleSize(self, n: int) -> None:
        """
        sets the visible size of the scroll bar.
        """
        ...

__all__ = ['XScrollBar']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Caret(object):
    """
    Struct Class

    This structure contains the caret information.
    
    This structure is used from the XTextLayout interface to transport information regarding a text caret.
    
    **since**
    
        OOo 2.0

    See Also:
        `API Caret <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1Caret.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.Caret'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.rendering.Caret'
    """Literal Constant ``com.sun.star.rendering.Caret``"""

    def __init__(self, MainCaretIndex: typing.Optional[int] = 0, SecondaryCaretIndex: typing.Optional[int] = 0, CaretAngle: typing.Optional[float] = 0.0) -> None:
        """
        Constructor

        Arguments:
            MainCaretIndex (int, optional): MainCaretIndex value.
            SecondaryCaretIndex (int, optional): SecondaryCaretIndex value.
            CaretAngle (float, optional): CaretAngle value.
        """
        super().__init__()

        if isinstance(MainCaretIndex, Caret):
            oth: Caret = MainCaretIndex
            self.MainCaretIndex = oth.MainCaretIndex
            self.SecondaryCaretIndex = oth.SecondaryCaretIndex
            self.CaretAngle = oth.CaretAngle
            return

        kargs = {
            "MainCaretIndex": MainCaretIndex,
            "SecondaryCaretIndex": SecondaryCaretIndex,
            "CaretAngle": CaretAngle,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._main_caret_index = kwargs["MainCaretIndex"]
        self._secondary_caret_index = kwargs["SecondaryCaretIndex"]
        self._caret_angle = kwargs["CaretAngle"]


    @property
    def MainCaretIndex(self) -> int:
        """
        This contains the main caret index.
        
        The main caret index corresponds to the insert position when inserting text in the layout's main text direction.
        """
        return self._main_caret_index

    @MainCaretIndex.setter
    def MainCaretIndex(self, value: int) -> None:
        self._main_caret_index = value

    @property
    def SecondaryCaretIndex(self) -> int:
        """
        This contains the secondary caret index.
        
        The secondary caret index, when different from the main caret index, corresponds to the insert position when inserting text at a direction change opposite to the layout's main text direction.
        """
        return self._secondary_caret_index

    @SecondaryCaretIndex.setter
    def SecondaryCaretIndex(self, value: int) -> None:
        self._secondary_caret_index = value

    @property
    def CaretAngle(self) -> float:
        """
        The angle of the caret.
        
        This member contains the rotation angle of the caret in degrees, with 0 denoting an unrotated caret (the unrotated caret orientation depends on the writing mode, horizontally or vertically). The rotation angle is positive for counter-clockwise rotations.
        """
        return self._caret_angle

    @CaretAngle.setter
    def CaretAngle(self, value: float) -> None:
        self._caret_angle = value


__all__ = ['Caret']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.tree
from __future__ import annotations
from .x_tree_control import XTreeControl as XTreeControl_e0500cfb

class TreeControl(XTreeControl_e0500cfb):
    """
    Service Class

    A control that displays a set of hierarchical data as an outline.
    
    A specific node in a tree is identified by a XTreeNode. A leaf node is a node without any children and that returns FALSE when calling XTreeNode.hasChildrenOnDemand(). An expanded node is a non-leaf node that will displays its children when all its ancestors are expanded. A collapsed node is one which hides them. A node is visible when all parent nodes are expanded and the node itself is in the display area.
    
    The nodes are retrieved from a XTreeDataModel. You can implement it yourself or use the MutableTreeDataModel which uses XMutableTreeNode and XMutableTreeDataModel for a simple and mutable data model.
    
    The data model must be set at the TreeControlModel.TreeDataModel property.
    
    If you are interested in knowing when the selection changes implement a com.sun.star.view.XSelectionChangeListener and add the instance with the method com.sun.star.view.XSelectionSupplier.addSelectionChangeListener(). You than will be notified for any selection change.
    
    If you are interested in detecting either double-click events or when a user clicks on a node, regardless of whether or not it was selected, you can get the com.sun.star.awt.XWindow and add yourself as a com.sun.star.awt.XMouseClickHandler. You can use the method XTreeControl.getNodeForLocation() to retrieve the node that was under the mouse at the time the event was fired.
    
    If you want to add child nodes to your tree on demand you can do the following.
    
    Now you get called when the node will become expanded or collapsed. So on XTreeExpansionListener.treeExpanding() you can check the TreeExpansionEvent if the parent node with children on demand is going to be expanded and in that case add the missing child nodes. You can also veto the expansion or collapsing of a parent node by using the ExpandVetoException.

    See Also:
        `API TreeControl <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1tree_1_1TreeControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.tree'
    __ooo_full_ns__: str = 'com.sun.star.awt.tree.TreeControl'
    __ooo_type_name__: str = 'service'


__all__ = ['TreeControl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_layer import XLayer as XLayer_4cd50fcb
    from .x_updatable_layer import XUpdatableLayer as XUpdatableLayer_ec97135d

class XMultiLayerStratum(XInterface_8f010a43):
    """
    Handles access to a stratum consisting of multiple layers in a single configuration data repository.
    
    The interface provides access to data for multiple entities and timestamp-checking capabilities for efficient caching.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XMultiLayerStratum <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XMultiLayerStratum.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.XMultiLayerStratum'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.backend.XMultiLayerStratum'

    @abstractmethod
    def getLayer(self, aLayerId: str, aTimestamp: str) -> XLayer_4cd50fcb:
        """
        retrieves a layer associated to a layer id, if newer than indicated.
        
        A timestamp can be provided, which is used to indicate a point in time. The layer should be returned only if is modified since that time.
        
        Layer ids can be obtained from XMultiLayerStratum.listLayerIds() or XMultiLayerStratum.getUpdateLayerId().
        
        An empty timestamp indicates, that the layer should be retrieved irrespective of its modification time.
        
        The format and meaning of a timestamp depends on the implementation. Timestamps can be obtained using com.sun.star.util.XTimeStamped.getTimestamp().

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getLayers(self, aLayerIds: typing.Tuple[str, ...], aTimestamp: str) -> typing.Tuple[XLayer_4cd50fcb, ...]:
        """
        retrieves the layers associated to a series of layer ids, if newer than indicated.
        
        A timestamp can be provided, which is used to indicate a point in time. Only layers that are modified since that time should be returned. The same timestamp is used for all layers.
        
        Layer ids can be obtained from XMultiLayerStratum.listLayerIds().
        
        An empty timestamp indicates, that the layers should be retrieved irrespective of their modification time.
        
        The format and meaning of a timestamp depends on the implementation. Timestamps can be obtained using com.sun.star.util.XTimeStamped.getTimestamp().
        
        The list has the same length as aLayerIds. Each layer object is associated to the layer id in the corresponding position.
        
        For layers that are newer than indicated by the timestamp, the list contains a NULL element.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getMultipleLayers(self, aLayerIds: typing.Tuple[str, ...], aTimestamps: typing.Tuple[str, ...]) -> typing.Tuple[XLayer_4cd50fcb, ...]:
        """
        retrieves the layers associated to a series of layer ids, if newer than indicated for each layer.
        
        For each layer an individual timestamp can be provided, which is used to indicate the last known version of the layer. Only layers that are modified since that time should be returned.
        
        Layer ids can be obtained from XMultiLayerStratum.listLayerIds().
        
        This list must have the same length as aLayerIds. Timestamps are matched to layer ids by their position.
        
        An empty timestamp indicates, that the associated layer should be retrieved irrespective of its modification time.
        
        The format and meaning of a timestamp depends on the implementation. Timestamps can be obtained using com.sun.star.util.XTimeStamped.getTimestamp().
        
        The list has the same length as aLayerIds. Each layer object is associated to the layer id in the corresponding position.
        
        For layers that are newer than indicated by the corresponding timestamp, the list contains a NULL element.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getUpdatableLayer(self, aLayerId: str) -> XUpdatableLayer_ec97135d:
        """
        retrieves a writable representation of the layer associated to a layer id.
        
        A layer id for writing can be obtained from XMultiLayerStratum.getUpdateLayerId().

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getUpdateLayerId(self, aComponent: str, aEntity: str) -> str:
        """
        identifies the layer which should be modified to update data of a component on behalf of an entity.
        
        The layer id returned is one of the layer ids obtained from XMultiLayerStratum.listLayerIds() for the same component and entity.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def listLayerIds(self, aComponent: str, aEntity: str) -> typing.Tuple[str, ...]:
        """
        identifies the layers within this stratum which should be read and merged to determine data of a component for an entity
        
        The list is ordered by priority. Typically the most general layers (global defaults, entire organization) are first, more specific layers (associated to specific groups or roles) are next and the entity's own data is last.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XMultiLayerStratum']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.container
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from .x_enumeration import XEnumeration as XEnumeration_f2180daa

class XContainerQuery(XInterface_8f010a43):
    """
    supports simple query feature on a container
    
    This interface makes it possible to create sub sets of container items which serve specified search criterion.

    See Also:
        `API XContainerQuery <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XContainerQuery.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.container'
    __ooo_full_ns__: str = 'com.sun.star.container.XContainerQuery'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.container.XContainerQuery'

    @abstractmethod
    def createSubSetEnumerationByProperties(self, Properties: typing.Tuple[NamedValue_a37a0af3, ...]) -> XEnumeration_f2180daa:
        """
        creates a sub set of container items which supports searched properties as minimum
        
        It's not possible to use special commands or search specific parameters here. You can match by properties only. Enumerated elements must provide queried properties as minimum. Not specified properties will not be used for searching.
        """
        ...
    @abstractmethod
    def createSubSetEnumerationByQuery(self, Query: str) -> XEnumeration_f2180daa:
        """
        creates a sub set of container items which match given query command
        
        Items of this sub set must match used query string. Format of query depends from real implementation. Using of \"param=value\" pairs isn't necessary. So it's possible to combine different parameters as one simple command string.
        """
        ...

__all__ = ['XContainerQuery']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class ForbiddenCharacters(object):
    """
    Struct Class

    Locale (mostly CJK) dependent characters that are forbidden at the start or end of a line.
    
    Returned by XLocaleData.getForbiddenCharacters() and used with XForbiddenCharacters methods.

    See Also:
        `API ForbiddenCharacters <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1ForbiddenCharacters.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.ForbiddenCharacters'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.ForbiddenCharacters'
    """Literal Constant ``com.sun.star.i18n.ForbiddenCharacters``"""

    def __init__(self, beginLine: typing.Optional[str] = '', endLine: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            beginLine (str, optional): beginLine value.
            endLine (str, optional): endLine value.
        """
        super().__init__()

        if isinstance(beginLine, ForbiddenCharacters):
            oth: ForbiddenCharacters = beginLine
            self.beginLine = oth.beginLine
            self.endLine = oth.endLine
            return

        kargs = {
            "beginLine": beginLine,
            "endLine": endLine,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._begin_line = kwargs["beginLine"]
        self._end_line = kwargs["endLine"]


    @property
    def beginLine(self) -> str:
        """
        Characters forbidden at the start of a line.
        """
        return self._begin_line

    @beginLine.setter
    def beginLine(self, value: str) -> None:
        self._begin_line = value

    @property
    def endLine(self) -> str:
        """
        Characters forbidden at the end of a line.
        """
        return self._end_line

    @endLine.setter
    def endLine(self, value: str) -> None:
        self._end_line = value


__all__ = ['ForbiddenCharacters']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .calendar_item2 import CalendarItem2 as CalendarItem2_b38f0b23


class Calendar2(object):
    """
    Struct Class

    Calendar items as returned in a sequence by XLocaleData3.getAllCalendars2().
    
    Similar to com.sun.star.i18n.Calendar this provides additional members with a sequence of possessive (genitive case) and partitive case month names for locales that use them, for example Slavic locales. If a locale does not provide the possessive form in GenitiveMonths, the names are identical to the nominative case nouns in Calendar.Months. If a locale does not provide the partitive case in PartitiveMonths, the names are identical to GenitiveMonths.
    
    The sequences are of type com.sun.star.i18n.CalendarItem2 instead of com.sun.star.i18n.CalendarItem, with the additional NarrowName member.
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API Calendar2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1Calendar2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.Calendar2'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.Calendar2'
    """Literal Constant ``com.sun.star.i18n.Calendar2``"""

    def __init__(self, Days: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = (), Months: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = (), GenitiveMonths: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = (), PartitiveMonths: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = (), Eras: typing.Optional[typing.Tuple[CalendarItem2_b38f0b23, ...]] = (), StartOfWeek: typing.Optional[str] = '', MinimumNumberOfDaysForFirstWeek: typing.Optional[int] = 0, Default: typing.Optional[bool] = False, Name: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Days (typing.Tuple[CalendarItem2, ...], optional): Days value.
            Months (typing.Tuple[CalendarItem2, ...], optional): Months value.
            GenitiveMonths (typing.Tuple[CalendarItem2, ...], optional): GenitiveMonths value.
            PartitiveMonths (typing.Tuple[CalendarItem2, ...], optional): PartitiveMonths value.
            Eras (typing.Tuple[CalendarItem2, ...], optional): Eras value.
            StartOfWeek (str, optional): StartOfWeek value.
            MinimumNumberOfDaysForFirstWeek (int, optional): MinimumNumberOfDaysForFirstWeek value.
            Default (bool, optional): Default value.
            Name (str, optional): Name value.
        """
        super().__init__()

        if isinstance(Days, Calendar2):
            oth: Calendar2 = Days
            self.Days = oth.Days
            self.Months = oth.Months
            self.GenitiveMonths = oth.GenitiveMonths
            self.PartitiveMonths = oth.PartitiveMonths
            self.Eras = oth.Eras
            self.StartOfWeek = oth.StartOfWeek
            self.MinimumNumberOfDaysForFirstWeek = oth.MinimumNumberOfDaysForFirstWeek
            self.Default = oth.Default
            self.Name = oth.Name
            return

        kargs = {
            "Days": Days,
            "Months": Months,
            "GenitiveMonths": GenitiveMonths,
            "PartitiveMonths": PartitiveMonths,
            "Eras": Eras,
            "StartOfWeek": StartOfWeek,
            "MinimumNumberOfDaysForFirstWeek": MinimumNumberOfDaysForFirstWeek,
            "Default": Default,
            "Name": Name,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._days = kwargs["Days"]
        self._months = kwargs["Months"]
        self._genitive_months = kwargs["GenitiveMonths"]
        self._partitive_months = kwargs["PartitiveMonths"]
        self._eras = kwargs["Eras"]
        self._start_of_week = kwargs["StartOfWeek"]
        self._minimum_number_of_days_for_first_week = kwargs["MinimumNumberOfDaysForFirstWeek"]
        self._default = kwargs["Default"]
        self._name = kwargs["Name"]


    @property
    def Days(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The days of the week.
        """
        return self._days

    @Days.setter
    def Days(self, value: typing.Tuple[CalendarItem2_b38f0b23, ...]) -> None:
        self._days = value

    @property
    def Months(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The months of the year.
        """
        return self._months

    @Months.setter
    def Months(self, value: typing.Tuple[CalendarItem2_b38f0b23, ...]) -> None:
        self._months = value

    @property
    def GenitiveMonths(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The months of the year in possessive genitive case.
        """
        return self._genitive_months

    @GenitiveMonths.setter
    def GenitiveMonths(self, value: typing.Tuple[CalendarItem2_b38f0b23, ...]) -> None:
        self._genitive_months = value

    @property
    def PartitiveMonths(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The months of the year in partitive case.
        """
        return self._partitive_months

    @PartitiveMonths.setter
    def PartitiveMonths(self, value: typing.Tuple[CalendarItem2_b38f0b23, ...]) -> None:
        self._partitive_months = value

    @property
    def Eras(self) -> typing.Tuple[CalendarItem2_b38f0b23, ...]:
        """
        The possible eras.
        """
        return self._eras

    @Eras.setter
    def Eras(self, value: typing.Tuple[CalendarItem2_b38f0b23, ...]) -> None:
        self._eras = value

    @property
    def StartOfWeek(self) -> str:
        """
        The ID of the day with which the week begins.
        """
        return self._start_of_week

    @StartOfWeek.setter
    def StartOfWeek(self, value: str) -> None:
        self._start_of_week = value

    @property
    def MinimumNumberOfDaysForFirstWeek(self) -> int:
        """
        How many days must reside in the first week of a year.
        """
        return self._minimum_number_of_days_for_first_week

    @MinimumNumberOfDaysForFirstWeek.setter
    def MinimumNumberOfDaysForFirstWeek(self, value: int) -> None:
        self._minimum_number_of_days_for_first_week = value

    @property
    def Default(self) -> bool:
        """
        If this is the default calendar for a given locale.
        """
        return self._default

    @Default.setter
    def Default(self, value: bool) -> None:
        self._default = value

    @property
    def Name(self) -> str:
        """
        The name of the calendar, for example, Gregorian.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value


__all__ = ['Calendar2']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from ..chart.x_chart_data_array import XChartDataArray as XChartDataArray_df4c0cdd
from ..container.x_named import XNamed as XNamed_a6520b08
from ..sheet.x_cell_range_data import XCellRangeData as XCellRangeData_d2e70c60
from ..table.x_auto_formattable import XAutoFormattable as XAutoFormattable_ee660d72
from ..table.x_cell_range import XCellRange as XCellRange_a2f70ad5
from .text_content import TextContent as TextContent_a6810b4d
from .x_text_table import XTextTable as XTextTable_9a810ab2
from ..util.x_sortable import XSortable as XSortable_8ff20a5a
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..table.shadow_format import ShadowFormat as ShadowFormat_bb840bdf
    from ..table.table_border import TableBorder as TableBorder_aedf0b56
    from .table_column_separator import TableColumnSeparator as TableColumnSeparator_1b630ed4
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.style.GraphicLocation import GraphicLocationProto
    from com.sun.star.style.BreakType import BreakTypeProto

class TextTable(TextContent_a6810b4d, UserDefinedAttributesSupplier_9fbe1222, XChartDataArray_df4c0cdd, XNamed_a6520b08, XCellRangeData_d2e70c60, XAutoFormattable_ee660d72, XCellRange_a2f70ad5, XTextTable_9a810ab2, XSortable_8ff20a5a):
    """
    Service Class

    is a table of text cells which is anchored to a surrounding text.
    
    Note: The anchor of the actual implementation for text tables does not have a position in the text. Thus that anchor can not be used for some operation like XTextContent.attach() or XText.insertTextContent() or other function that require the object to have a position in the text.
    
    The reason why a text table still needs an anchor is that for example tables should be insertable via XText.insertTextContent() and that interface uses a parameter of that type.
    
    Example: Create and insert a TextTable:
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API TextTable <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextTable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.TextTable'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def TableColumnSeparators(self) -> typing.Tuple[TableColumnSeparator_1b630ed4, ...]:
        """
        contains the column description of the table.
        """
        ...

    @abstractproperty
    def TableInteropGrabBag(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Grab bag of table properties, used as a string-any map for interim interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def BackColor(self) -> Color_68e908c5:
        """
        contains the color of the background.
        """
        ...

    @abstractproperty
    def BackGraphic(self) -> XGraphic_a4da0afc:
        """
        contains the graphic for the background.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def BackGraphicFilter(self) -> str:
        """
        contains the name of the file filter for the background graphic.
        """
        ...

    @abstractproperty
    def BackGraphicLocation(self) -> GraphicLocationProto:
        """
        determines the position of the background graphic.
        """
        ...

    @abstractproperty
    def BackGraphicURL(self) -> str:
        """
        contains the URL for the background graphic.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the BackGraphic property.
        """
        ...

    @abstractproperty
    def BackTransparent(self) -> bool:
        """
        determines if the background color is transparent.
        """
        ...

    @abstractproperty
    def BottomMargin(self) -> int:
        """
        determines the bottom margin.
        """
        ...

    @abstractproperty
    def BreakType(self) -> BreakTypeProto:
        """
        determines the type of break that is applied at the beginning of the table.
        """
        ...

    @abstractproperty
    def ChartColumnAsLabel(self) -> bool:
        """
        determines if the first column of the table should be treated as axis labels when a chart is to be created.
        """
        ...

    @abstractproperty
    def ChartRowAsLabel(self) -> bool:
        """
        determines if the first row of the table should be treated as axis labels when a chart is to be created.
        """
        ...

    @abstractproperty
    def CollapsingBorders(self) -> bool:
        """
        determines whether borders of neighboring table cells are collapsed into one
        """
        ...

    @abstractproperty
    def HeaderRowCount(self) -> int:
        """
        determines the number of rows of the table repeated on every new page.
        """
        ...

    @abstractproperty
    def HoriOrient(self) -> int:
        """
        contains the horizontal orientation.
        """
        ...

    @abstractproperty
    def IsWidthRelative(self) -> bool:
        """
        determines if the value of the relative width is valid.
        """
        ...

    @abstractproperty
    def KeepTogether(self) -> bool:
        """
        Setting this property to TRUE prevents page or column breaks between this table and the following paragraph or text table.
        """
        ...

    @abstractproperty
    def LeftMargin(self) -> int:
        """
        contains the left margin of the table.
        """
        ...

    @abstractproperty
    def PageDescName(self) -> str:
        """
        If this property is set, it creates a page break before the table and assigns the value as the name of the new page style sheet to use.
        """
        ...

    @abstractproperty
    def PageNumberOffset(self) -> int:
        """
        If a page break property is set at the table, this property contains the new value for the page number.
        """
        ...

    @abstractproperty
    def RelativeWidth(self) -> int:
        """
        determines the width of the table relative to its environment.
        """
        ...

    @abstractproperty
    def RepeatHeadline(self) -> bool:
        """
        determines if the first row of the table is repeated on every new page.
        """
        ...

    @abstractproperty
    def RightMargin(self) -> int:
        """
        contains the right margin of the table.
        """
        ...

    @abstractproperty
    def ShadowFormat(self) -> ShadowFormat_bb840bdf:
        """
        determines the type, color and size of the shadow.
        """
        ...

    @abstractproperty
    def Split(self) -> bool:
        """
        Setting this property to FALSE prevents the table from getting spread on two pages.
        """
        ...

    @abstractproperty
    def TableBorder(self) -> TableBorder_aedf0b56:
        """
        contains the description of the table borders.
        """
        ...

    @abstractproperty
    def TableColumnRelativeSum(self) -> int:
        """
        contains the sum of the column width values used in TableColumnSeparators.
        """
        ...

    @abstractproperty
    def TableTemplateName(self) -> str:
        """
        contains the name of table style used by the table.
        
        **since**
        
            LibreOffice 5.3
        """
        ...

    @abstractproperty
    def TopMargin(self) -> int:
        """
        determines the top margin.
        """
        ...

    @abstractproperty
    def Width(self) -> int:
        """
        contains the absolute table width.
        
        As this is only a describing property the value of the actual table may vary depending on the environment the table is located in and the settings of LeftMargin, RightMargin and HoriOrient.
        """
        ...


__all__ = ['TextTable']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .chart_data_change_type import ChartDataChangeType as ChartDataChangeType_16cc0e6e


class ChartDataChangeEvent(EventObject_a3d70b03):
    """
    Struct Class

    describes a change that was applied to the data.

    See Also:
        `API ChartDataChangeEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart_1_1ChartDataChangeEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartDataChangeEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart.ChartDataChangeEvent'
    """Literal Constant ``com.sun.star.chart.ChartDataChangeEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Type: typing.Optional[ChartDataChangeType_16cc0e6e] = ChartDataChangeType_16cc0e6e.ALL, StartColumn: typing.Optional[int] = 0, EndColumn: typing.Optional[int] = 0, StartRow: typing.Optional[int] = 0, EndRow: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Type (ChartDataChangeType, optional): Type value.
            StartColumn (int, optional): StartColumn value.
            EndColumn (int, optional): EndColumn value.
            StartRow (int, optional): StartRow value.
            EndRow (int, optional): EndRow value.
        """

        if isinstance(Source, ChartDataChangeEvent):
            oth: ChartDataChangeEvent = Source
            self.Source = oth.Source
            self.Type = oth.Type
            self.StartColumn = oth.StartColumn
            self.EndColumn = oth.EndColumn
            self.StartRow = oth.StartRow
            self.EndRow = oth.EndRow
            return

        kargs = {
            "Source": Source,
            "Type": Type,
            "StartColumn": StartColumn,
            "EndColumn": EndColumn,
            "StartRow": StartRow,
            "EndRow": EndRow,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._type = kwargs["Type"]
        self._start_column = kwargs["StartColumn"]
        self._end_column = kwargs["EndColumn"]
        self._start_row = kwargs["StartRow"]
        self._end_row = kwargs["EndRow"]
        inst_keys = ('Type', 'StartColumn', 'EndColumn', 'StartRow', 'EndRow')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Type(self) -> ChartDataChangeType_16cc0e6e:
        """
        specifies the type of change to the data.
        """
        return self._type

    @Type.setter
    def Type(self, value: ChartDataChangeType_16cc0e6e) -> None:
        self._type = value

    @property
    def StartColumn(self) -> int:
        """
        specifies the column number in which the changes begin.
        """
        return self._start_column

    @StartColumn.setter
    def StartColumn(self, value: int) -> None:
        self._start_column = value

    @property
    def EndColumn(self) -> int:
        """
        specifies the column number in which the changes end.
        """
        return self._end_column

    @EndColumn.setter
    def EndColumn(self, value: int) -> None:
        self._end_column = value

    @property
    def StartRow(self) -> int:
        """
        specifies the row number in which the changes begin.
        """
        return self._start_row

    @StartRow.setter
    def StartRow(self, value: int) -> None:
        self._start_row = value

    @property
    def EndRow(self) -> int:
        """
        specifies the row number in which the changes end.
        """
        return self._end_row

    @EndRow.setter
    def EndRow(self, value: int) -> None:
        self._end_row = value


__all__ = ['ChartDataChangeEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_extended_storage_stream import XExtendedStorageStream as XExtendedStorageStream_46750fcf

class XHierarchicalStorageAccess(ABC):
    """
    This interface allows hierarchical access to storage tree.
    
    Currently only streams can be opened using this interface.
    
    The hierarchical access can not be mixed with a normal access. Thus when in a storage a stream with a path \"a/b/c\" is accessed using hierarchical access, another stream \"a/b/d\" can also be opened with hierarchical access ( if it is still not opened ), but the substorage \"a\" can not be opened ( it is locked by hierarchical access ).

    See Also:
        `API XHierarchicalStorageAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XHierarchicalStorageAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XHierarchicalStorageAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XHierarchicalStorageAccess'

    @abstractmethod
    def openEncryptedStreamElementByHierarchicalName(self, sStreamName: str, nOpenMode: int, sPassword: str) -> XExtendedStorageStream_46750fcf:
        """
        allows to get access to a child encrypted stream with password using hierarchical path.
        
        If storage does not allow any encryption this method will always throw com.sun.star.packages.NoEncryptionException.
        
        In case the stream is open in readonly mode the com.sun.star.io.XStream.getOutputStream() method will return an empty reference.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.NoEncryptionException: ``NoEncryptionException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...
    @abstractmethod
    def openStreamElementByHierarchicalName(self, sStreamPath: str, nOpenMode: int) -> XExtendedStorageStream_46750fcf:
        """
        allows to get access to a child stream of the storage, using hierarchical path.
        
        In case the stream is open in readonly mode the com.sun.star.io.XStream.getOutputStream() method will return an empty reference.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...
    @abstractmethod
    def removeStreamElementByHierarchicalName(self, sElementPath: str) -> None:
        """
        removes a stream specified by hierarchical name from a storage.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...

__all__ = ['XHierarchicalStorageAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ...util.url import URL as URL_57ad07b9
    from com.sun.star.drawing.framework.AnchorBindingMode import AnchorBindingModeProto

class XResourceId(ABC):
    """
    A resource id uses a set of URLs to unambiguously specify a resource of the drawing framework.
    
    Resources of the drawing framework are panes, views, tool bars, and command groups. One URL describes the type of the actual resource. A sequence of URLs (typically one, sometimes two) specifies its anchor, the resource it is bound to. The anchor typically is a pane (for views), or it is empty (for panes).
    
    The resource URL may be empty. In this case the anchor is empty, too. Such an empty resource id does not describe a resource but rather the absence of one. Instead of an empty XResourceId object an empty reference can be used in many places.
    
    The resource URL may have arguments that are passed to the factory method on its creation. Arguments are only available through the getFullResourceURL(). The getResourceURL() method strips them away.

    See Also:
        `API XResourceId <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XResourceId.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XResourceId'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XResourceId'

    @abstractmethod
    def clone(self) -> XResourceId:
        """
        Return a copy of the called resource id.
        
        The caller becomes the owner of the new object.
        """
        ...
    @abstractmethod
    def compareTo(self, xId: XResourceId) -> int:
        """
        Compare the called XResourceId object with the given one.
        
        The two resource ids A and B are compared so that if A<B (return value is -1) then either A and B are unrelated or A is a direct or indirect anchor of B.
        
        The algorithm for this comparison is quite simple. It uses a double lexicographic ordering. On the lower level individual URLs are compared via the lexicographic order defined on strings. On the higher level two resource ids are compared via a lexicographic order defined on the URLS. So when there are two resource ids A1.A2 (A1 being the anchor of A2) and B1.B2 then A1.A2<B1.B2 when A1<B1 or A1==B1 and A2<B2. Resource ids may have different lengths: A1 < B1.B2 when A1<B1 or A1==B1 (anchors first then resources linked to them.
        """
        ...
    @abstractmethod
    def getAnchor(self) -> XResourceId:
        """
        Return a new XResourceId that represents the anchor resource.
        """
        ...
    @abstractmethod
    def getAnchorURLs(self) -> typing.Tuple[str, ...]:
        """
        Return the, possibly empty, list of anchor URLs.
        
        The URLs are ordered so that the one in position 0 is the direct anchor of the resource, while the one in position i+1 is the direct anchor of the one in position i.
        """
        ...
    @abstractmethod
    def getFullResourceURL(self) -> URL_57ad07b9:
        """
        Return a URL object of the resource URL that may contain arguments.
        """
        ...
    @abstractmethod
    def getResourceTypePrefix(self) -> str:
        """
        Return the type prefix of the resource URL.
        
        This includes all up to and including the second slash.
        """
        ...
    @abstractmethod
    def getResourceURL(self) -> str:
        """
        Return the URL of the resource.
        
        Arguments supplied on creation are stripped away. Use getFullResourceURL() to access them.
        """
        ...
    @abstractmethod
    def hasAnchor(self) -> bool:
        """
        Return whether there is a non-empty anchor URL.
        
        When this method returns FALSE then getAnchorURLs() will return an empty list.
        """
        ...
    @abstractmethod
    def isBoundTo(self, xAnchorId: XResourceId, eMode: AnchorBindingModeProto) -> bool:
        """
        Return whether the anchor of the called resource id object represents the same resource as the given object.
        
        Note that not only the anchor of the given object is taken into account. The whole object, including the resource URL, is interpreted as anchor resource.
        
        If eMode is DIRECT then the anchor of the called resource id has to be identical to the given anchor. If eMode is INDIRECT then the given anchor has to be a part of the anchor of the called resource.
        """
        ...
    @abstractmethod
    def isBoundToURL(self, AnchorURL: str, eMode: AnchorBindingModeProto) -> bool:
        """
        Return whether the anchor of the called resource id object represents the same resource as the given anchor URL.
        
        This is a convenience variant of the isBoundTo() function that can also be seen as an optimization for the case that the anchor consists of exactly one URL.
        """
        ...

__all__ = ['XResourceId']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..drawing.x_shapes import XShapes as XShapes_9a800ab0
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_group import XGroup as XGroup_86540a09
    from .x_report_definition import XReportDefinition as XReportDefinition_ec30e81
    from ..util.color import Color as Color_68e908c5

class XSection(XPropertySet_bc180bfa, XChild_a6390b07, XContainer_d6fb0cc6, XEnumerationAccess_4bac0ffc, XShapes_9a800ab0, XComponent_98dc0ab5):
    """
    identifies a XSection inside a report.
    
    A section acts like a container of report components. This generic construction allows the definition of hierarchies of reports and their dependent subreports.

    See Also:
        `API XSection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XSection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.XSection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.XSection'

    @abstractproperty
    def BackColor(self) -> Color_68e908c5:
        """
        Defines the background color of the section.
        """
        ...

    @abstractproperty
    def BackTransparent(self) -> bool:
        """
        determines if the background color is set to transparent.
        """
        ...

    @abstractproperty
    def CanGrow(self) -> bool:
        """
        Specifies that elements with dynamic state will be expanded vertically when then content of the element is larger than it's container.
        
        If this property is disabled the content will be truncated when its size is larger than the container.
        """
        ...

    @abstractproperty
    def CanShrink(self) -> bool:
        """
        Represents ...
        """
        ...

    @abstractproperty
    def ConditionalPrintExpression(self) -> str:
        """
        Defines the expression which is executed before printing the section.
        
        If the return value of the expression is TRUE then the section will be printed.
        """
        ...

    @abstractproperty
    def ForceNewPage(self) -> int:
        """
        Specifies whether the section is printed on a separate page.
        
        Not valid for page header or page footer.
        """
        ...

    @abstractproperty
    def Group(self) -> XGroup_86540a09:
        """
        Specifies the parent of the section if it is a group header or group footer.
        """
        ...

    @abstractproperty
    def Height(self) -> int:
        """
        Defines the height of the section.
        """
        ...

    @abstractproperty
    def KeepTogether(self) -> bool:
        """
        Specifies that the section is printed on one page.
        
        Not valid for page header or page footer.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        Defines the name of the section.
        """
        ...

    @abstractproperty
    def NewRowOrCol(self) -> int:
        """
        Specifies whether the section is printed in a new row or column within a multi column report.
        
        Not valid for page header or page footer.
        """
        ...

    @abstractproperty
    def RepeatSection(self) -> bool:
        """
        Defines that the group header should be repeated on the next page when a group spans more than one page.
        
        It only applies to group headers.
        """
        ...

    @abstractproperty
    def ReportDefinition(self) -> XReportDefinition_ec30e81:
        """
        Specifies the parent of the section if it is a page header or page footer.
        """
        ...

    @abstractproperty
    def Visible(self) -> bool:
        """
        Defines if the section should be visible in report.
        """
        ...


__all__ = ['XSection']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.security
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
from .x_certificate import XCertificate as XCertificate_e55b0d3b


class DocumentSignatureInformation(object):
    """
    Struct Class

    Status of digital signatures in a document.
    
    This structure has the information about a digital signature in a document, and the status if the signature is valid.
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API DocumentSignatureInformation <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1security_1_1DocumentSignatureInformation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.security'
    __ooo_full_ns__: str = 'com.sun.star.security.DocumentSignatureInformation'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.security.DocumentSignatureInformation'
    """Literal Constant ``com.sun.star.security.DocumentSignatureInformation``"""

    def __init__(self, Signer: typing.Optional[XCertificate_e55b0d3b] = None, SignatureDate: typing.Optional[int] = 0, SignatureTime: typing.Optional[int] = 0, SignatureIsValid: typing.Optional[bool] = False, CertificateStatus: typing.Optional[int] = 0, PartialDocumentSignature: typing.Optional[bool] = False, SignatureLineId: typing.Optional[str] = '', ValidSignatureLineImage: typing.Optional[XGraphic_a4da0afc] = None, InvalidSignatureLineImage: typing.Optional[XGraphic_a4da0afc] = None) -> None:
        """
        Constructor

        Arguments:
            Signer (XCertificate, optional): Signer value.
            SignatureDate (int, optional): SignatureDate value.
            SignatureTime (int, optional): SignatureTime value.
            SignatureIsValid (bool, optional): SignatureIsValid value.
            CertificateStatus (int, optional): CertificateStatus value.
            PartialDocumentSignature (bool, optional): PartialDocumentSignature value.
            SignatureLineId (str, optional): SignatureLineId value.
            ValidSignatureLineImage (XGraphic, optional): ValidSignatureLineImage value.
            InvalidSignatureLineImage (XGraphic, optional): InvalidSignatureLineImage value.
        """
        super().__init__()

        if isinstance(Signer, DocumentSignatureInformation):
            oth: DocumentSignatureInformation = Signer
            self.Signer = oth.Signer
            self.SignatureDate = oth.SignatureDate
            self.SignatureTime = oth.SignatureTime
            self.SignatureIsValid = oth.SignatureIsValid
            self.CertificateStatus = oth.CertificateStatus
            self.PartialDocumentSignature = oth.PartialDocumentSignature
            self.SignatureLineId = oth.SignatureLineId
            self.ValidSignatureLineImage = oth.ValidSignatureLineImage
            self.InvalidSignatureLineImage = oth.InvalidSignatureLineImage
            return

        kargs = {
            "Signer": Signer,
            "SignatureDate": SignatureDate,
            "SignatureTime": SignatureTime,
            "SignatureIsValid": SignatureIsValid,
            "CertificateStatus": CertificateStatus,
            "PartialDocumentSignature": PartialDocumentSignature,
            "SignatureLineId": SignatureLineId,
            "ValidSignatureLineImage": ValidSignatureLineImage,
            "InvalidSignatureLineImage": InvalidSignatureLineImage,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._signer = kwargs["Signer"]
        self._signature_date = kwargs["SignatureDate"]
        self._signature_time = kwargs["SignatureTime"]
        self._signature_is_valid = kwargs["SignatureIsValid"]
        self._certificate_status = kwargs["CertificateStatus"]
        self._partial_document_signature = kwargs["PartialDocumentSignature"]
        self._signature_line_id = kwargs["SignatureLineId"]
        self._valid_signature_line_image = kwargs["ValidSignatureLineImage"]
        self._invalid_signature_line_image = kwargs["InvalidSignatureLineImage"]


    @property
    def Signer(self) -> XCertificate_e55b0d3b:
        return self._signer

    @Signer.setter
    def Signer(self, value: XCertificate_e55b0d3b) -> None:
        self._signer = value

    @property
    def SignatureDate(self) -> int:
        return self._signature_date

    @SignatureDate.setter
    def SignatureDate(self, value: int) -> None:
        self._signature_date = value

    @property
    def SignatureTime(self) -> int:
        """
        Time of day, in 100th of seconds.
        """
        return self._signature_time

    @SignatureTime.setter
    def SignatureTime(self, value: int) -> None:
        self._signature_time = value

    @property
    def SignatureIsValid(self) -> bool:
        return self._signature_is_valid

    @SignatureIsValid.setter
    def SignatureIsValid(self, value: bool) -> None:
        self._signature_is_valid = value

    @property
    def CertificateStatus(self) -> int:
        """
        Reflects the validity of the certificate.
        
        Contains a value from the constants of com.sun.star.security.CertificateValidity.
        """
        return self._certificate_status

    @CertificateStatus.setter
    def CertificateStatus(self, value: int) -> None:
        self._certificate_status = value

    @property
    def PartialDocumentSignature(self) -> bool:
        """
        Indicates what content of a document is signed.
        
        This value can be ignored when this struct is returned as part of a macro signature validation. As of OpenOffice.org 3.2 and ODF 1.2 the document signature comprises all files except the signature file itself. Signatures in OOo 2.x were only applied to the files in the root of the document, except mimetype, the Pictures and ObjectReplacements/Objects folder. That is, macros were not part of the document signature. OOo 3.0 signed everything, except mimetype and the META-INF folder.
        
        If PartialDocumentSignature is true, then the signature was created by OOo with a version lower than 3.2. In this case, not all files are signed. The signature can still be regarded as valid, as long as SignatureIsValid is true and the certificate could be validated. However, users should be notified about the fact, that not everything in this document is signed.
        """
        return self._partial_document_signature

    @PartialDocumentSignature.setter
    def PartialDocumentSignature(self, value: bool) -> None:
        self._partial_document_signature = value

    @property
    def SignatureLineId(self) -> str:
        """
        The ID of the Signature Line.
        
        **since**
        
            LibreOffice 6.0
        """
        return self._signature_line_id

    @SignatureLineId.setter
    def SignatureLineId(self, value: str) -> None:
        self._signature_line_id = value

    @property
    def ValidSignatureLineImage(self) -> XGraphic_a4da0afc:
        """
        The Signature Line Image which is shown when the signature is valid.
        
        **since**
        
            LibreOffice 6.0
        """
        return self._valid_signature_line_image

    @ValidSignatureLineImage.setter
    def ValidSignatureLineImage(self, value: XGraphic_a4da0afc) -> None:
        self._valid_signature_line_image = value

    @property
    def InvalidSignatureLineImage(self) -> XGraphic_a4da0afc:
        """
        The Signature Line Image which is shown when the signature is invalid.
        
        **since**
        
            LibreOffice 6.0
        """
        return self._invalid_signature_line_image

    @InvalidSignatureLineImage.setter
    def InvalidSignatureLineImage(self, value: XGraphic_a4da0afc) -> None:
        self._invalid_signature_line_image = value


__all__ = ['DocumentSignatureInformation']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util


class NumberFormat(object):
    """
    Const Class

    contains constants that are used to specify the type of a number format.

    See Also:
        `API NumberFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1util_1_1NumberFormat.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.NumberFormat'
    __ooo_type_name__: str = 'const'

    ALL = 0
    """
    selects all number formats.
    """
    DEFINED = 1
    """
    selects only user-defined number formats.
    """
    DATE = 2
    """
    selects date formats.
    """
    TIME = 4
    """
    selects time formats.
    """
    CURRENCY = 8
    """
    selects currency formats.
    """
    NUMBER = 16
    """
    selects decimal number formats.
    """
    SCIENTIFIC = 32
    """
    selects scientific number formats.
    """
    FRACTION = 64
    """
    selects number formats for fractions.
    """
    PERCENT = 128
    """
    selects percentage number formats.
    """
    TEXT = 256
    """
    selects text number formats.
    """
    DATETIME = 6
    """
    selects number formats which contain date and time.
    """
    LOGICAL = 1024
    """
    selects boolean number formats.
    """
    UNDEFINED = 2048
    """
    is used as a return value if no format exists.
    """
    EMPTY = 4096
    DURATION = 8196

__all__ = ['NumberFormat']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.lang
from __future__ import annotations
import typing
from abc import abstractproperty
from .service_manager import ServiceManager as ServiceManager_c7920c36
from .x_initialization import XInitialization as XInitialization_d46c0cca
if typing.TYPE_CHECKING:
    from ..registry.x_simple_registry import XSimpleRegistry as XSimpleRegistry_10150e9c

class RegistryServiceManager(ServiceManager_c7920c36, XInitialization_d46c0cca):
    """
    Service Class

    Provides a collection of implementations for services reading from a persistent registry storage.
    
    For usage of the service manager have a look at service description of ServiceManager.

    See Also:
        `API RegistryServiceManager <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1lang_1_1RegistryServiceManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.RegistryServiceManager'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Registry(self) -> XSimpleRegistry_10150e9c:
        """
        Specifies the current registry to be read from.
        """
        ...


__all__ = ['RegistryServiceManager']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.auth
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .xsso_acceptor_context import XSSOAcceptorContext as XSSOAcceptorContext_6960e1d
    from .xsso_initiator_context import XSSOInitiatorContext as XSSOInitiatorContext_168c0e9f

class XSSOManager(XInterface_8f010a43):
    """
    supports the creation of security contexts for both the initiator/source side and the acceptor/target side.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XSSOManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1auth_1_1XSSOManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.auth'
    __ooo_full_ns__: str = 'com.sun.star.auth.XSSOManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.auth.XSSOManager'

    @abstractmethod
    def createAcceptorContext(self, TargetPrincipal: str) -> XSSOAcceptorContext_6960e1d:
        """
        creates an acceptor side security context.

        Raises:
            InvalidArgumentException: ``InvalidArgumentException``
            InvalidCredentialException: ``InvalidCredentialException``
            InvalidPrincipalException: ``InvalidPrincipalException``
            UnsupportedException: ``UnsupportedException``
        """
        ...
    @abstractmethod
    def createInitiatorContext(self, SourcePrincipal: str, TargetPrincipal: str, TargetHost: str) -> XSSOInitiatorContext_168c0e9f:
        """
        creates an initiator side security context.

        Raises:
            InvalidArgumentException: ``InvalidArgumentException``
            InvalidCredentialException: ``InvalidCredentialException``
            InvalidPrincipalException: ``InvalidPrincipalException``
            UnsupportedException: ``UnsupportedException``
        """
        ...
    @abstractmethod
    def getMechanism(self) -> str:
        """
        retrieves the mechanism name of all security contexts created using this manager.
        """
        ...

__all__ = ['XSSOManager']

